<?php

namespace AppBundle\Controller;

use AppBundle\Form\UserEditType;
use AppBundle\Form\UserRegisterType;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use AppBundle\Form\UserType;
use AppBundle\Entity\User;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;

class SecurityController extends Controller
{
    public function loginAction(Request $request)
    {
        if ($this->get('security.authorization_checker')->isGranted('IS_AUTHENTICATED_REMEMBERED')) {
            return $this->redirectToRoute('videotheque_liste');
        }

        $authenticationUtils = $this->get('security.authentication_utils');

        return $this->render('@App/security/login.html.twig', array (
            'last_username' =>  $authenticationUtils->getLastUsername(),
            'error'         =>  $authenticationUtils->getLastAuthenticationError()
        ));
    }

    /**
     * @Route("/admin/createuser", name="admin_createuser")
     */
    public function createUserAction(Request $request, UserPasswordEncoderInterface $encoder)
    {
        $user = new User;
        $form = $this->createForm(UserType::class, $user);

        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid())
        {
            $user = $form->getData();
            $encoded = $encoder->encodePassword($user, $user->getPassword());
            $user->setPassword($encoded);
            $em = $this->getDoctrine()->getManager();
            $em->persist($user);
            $em->flush();
            $this->addFlash('success', 'L\'utilisateur a été ajouté');
            return $this->redirectToRoute('admin_index');
        }
        return $this->render('@App/security/createuser.html.twig', array (
            'form'  => $form->createView()
        ));
    }

    /**
     * @Route("/admin/edituser/{id}", name="admin_edituser")
     */
    public function editUserAction(Request $request, UserPasswordEncoderInterface $encoder, User $user)
    {
        $form = $this->createForm(UserEditType::class, $user);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid())
        {
            $em = $this->getDoctrine()->getManager();
            $user = $form->getData();
            $em->flush();
            $this->addFlash('success', 'L\'utilisateur a été modifié');
            return $this->redirectToRoute('admin_index');
        }
        return $this->render('@App/security/createuser.html.twig', array (
            'form'  => $form->createView()
        ));
    }

    /**
     * @Route("/admin", name="admin_index")
     */
    public function indexAction(Request $request)
    {
        $em = $this->getDoctrine()->getManager();
        $repo = $em->getRepository('AppBundle:User');
        $users = $repo->findAll();

        return $this->render('@App/security/liste.html.twig', array(
            'users' => $users
        ));
    }

    /**
     * @Route("/admin/deluser/{id}", name="admin_deluser")
     */
    public function delUserAction (Request $request, User $user)
    {
        $form = $this->get('form.factory')->create();
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($user);
            $em->flush();
            $this->addFlash("success", "L'utilisateur a bien été supprimé");
            return $this->redirectToRoute('admin_index');
        }
        return $this->render('@App/security/supprimeruser.html.twig', array (
            'user'  =>  $user,
            'form'  =>  $form->createView()
        ));
    }

    /**
     * @Route("/register", name="security_register")
     */
    public function registerAction(Request $request, UserPasswordEncoderInterface $encoder)
    {
        $user = new User();
        $form = $this->createForm(UserRegisterType::class, $user);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid())
        {
            $user = $form->getData();
            $user->setRoles(array('ROLE_USER'));
            $encoded = $encoder->encodePassword($user, $user->getPassword());
            $user->setPassword($encoded);
            $em = $this->getDoctrine()->getManager();
            $em->persist($user);
            $em->flush();
            $this->addFlash('success', 'Votre compte a été créé. Vous pouvez vous identifier');
            return $this->redirectToRoute('login');
        }

        return $this->render('@App/security/register.html.twig', array(
            'form'  => $form->createView()
        ));
    }


}